//DESCRIPTION:Add a .5 pt solid black horizontal row stroke every 5 rows within the selection. A stroke above and below the selection will also be added. The entire row will be affected, even if only a single cell in the row is selected. All other horizontal strokes in the affected rows will be removed.

// Keith Gilbert
// gilbertconsulting.com

// Modified 2019-10-03

// Make the script un-doable with one command
app.doScript(Main, undefined, undefined, UndoModes.ENTIRE_SCRIPT,"Run Script");

function Main() {
    // Check to see whether any InDesign documents are open.
    if (app.documents.length == 0) {
        alert("No InDesign documents are open. Please open a document and try again.");
        return;
    }
    // Check to see if exactly 1 item is selected
    if (app.selection.length != 1) {
        alert("Please select some cells and try again.");
        return;
    }
	var myDoc = app.activeDocument;
	// Evaluate the selection based on its type. In this case, if either a Table or Cell is selected, then the lines below
	// Cell are evaluated. The other constructor names are included for example purposes. 
	switch (app.selection[0].constructor.name){
		case "Table":
		case "Cell":
			myCreateRules(myDoc);
			// myApplyCellStyle(myDoc);
			break;
		case "InsertionPoint":
		case "Character":
		case "Word":
		case "TextStyleRange":
		case "Line":
		case "Paragraph":
		case "TextColumn":
		case "Text":
		case "Story":
		case "TextFrame":
		case "TextBox":
		case "GraphicLine":
		case "Rectangle":
		case "Oval":
		case "Polygon":
		case "EPS":
		case "PDF":
		case "ImportedPage":
		case "Image":
		case "Group":
		default:
			alert("Please select some cells and try again.");
			break;
	}
}
// Add a .5pt rule every 5 lines
function myCreateRules(myDoc) {
	// Delete all horizontal rules in the selection
	myDoc.selection[0].rows.everyItem().topEdgeStrokeWeight = "0pt";
	// Add a rule every 5 rows
	var mySelection = myDoc.selection[0].rows.everyItem().getElements(); // Create an array of all the rows in the selection
	var myNumRows = mySelection.length;
	for (var i=0; i<myNumRows; i=i+5) {
		mySelection[i].topEdgeStrokeWeight = ".5pt";
		mySelection[i].topEdgeStrokeType = "Solid";
		mySelection[i].topEdgeStrokeColor = "Black";
	}
	// Add a rule at the bottom of the selection
	mySelection[myNumRows-1].bottomEdgeStrokeWeight = ".5pt";
	mySelection[myNumRows-1].bottomEdgeStrokeType = "Solid";
	mySelection[myNumRows-1].bottomEdgeStrokeColor = "Black";
}
// Apply a cell style every 5 lines
function myApplyCellStyle(myDoc) {
	// Check to see if the cell style exists
	if (!myDoc.cellStyles.item("cell_highlight").isValid) { // Cell style doesn't exist
		// Create the cell style and make give it a 50% black fill
		myDoc.cellStyles.add({name:"cell_highlight",fillColor:"Black",fillTint:50});
	}
	// Apply a cell style of none to the entire selection
	myDoc.selection[0].rows.everyItem().cells.everyItem().appliedCellStyle = myDoc.cellStyles.itemByName("[None]");;
	// Apply the cell style every 5 rows
	var mySelection = myDoc.selection[0].rows.everyItem().getElements(); // Create an array of all the rows in the selection
	var myNumRows = mySelection.length;
	for (var i=0; i<myNumRows; i=i+5) { // Iterate through every 5th row in the table
		var myRow = mySelection[i];
		for (var j=0; j<myRow.cells.length; j=j+1) { // Iterate through each cell in the row
			var myCell = myRow.cells[j];
			myCell.appliedCellStyle = myDoc.cellStyles.itemByName("cell_highlight");
		}
	}
}